@@ -1,5 +1,5 @@
 package CPAN::Testers::Schema::Result::TestReport;
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 # ABSTRACT: Raw reports as JSON documents
 
 #pod =head1 SYNOPSIS
@@ -24,9 +24,10 @@ our $VERSION = '0.019';
 use CPAN::Testers::Schema::Base 'Result';
 use Data::UUID;
 use DateTime;
+use JSON::MaybeXS;
 table 'test_report';
 
-__PACKAGE__->load_components('InflateColumn::Serializer', 'InflateColumn::DateTime', 'Core');
+__PACKAGE__->load_components('InflateColumn::DateTime', 'Core');
 
 #pod =attr id
 #pod
@@ -69,10 +70,26 @@ column created => {
 column 'report', {
     data_type            => 'JSON',
     is_nullable          => 0,
-    'serializer_class'   => 'JSON',
-    'serializer_options' => { allow_blessed => 1, convert_blessed => 1, ascii => 1 }
 };
 
+my %JSON_OPT = (
+    allow_blessed => 1,
+    convert_blessed => 1,
+    ascii => 1,
+);
+__PACKAGE__->inflate_column( report => {
+    deflate => sub {
+        my ( $ref, $row ) = @_;
+        JSON::MaybeXS->new( %JSON_OPT )->encode( $ref );
+    },
+    inflate => sub {
+        my ( $raw, $row ) = @_;
+        JSON::MaybeXS->new( %JSON_OPT )->decode(
+            $raw =~ s/([\x{0000}-\x{001f}])/sprintf "\\u%v04x", $1/reg
+        );
+    },
+} );
+
 #pod =method new
 #pod
 #pod Create a new object. This is called automatically by the ResultSet
@@ -117,7 +134,7 @@ CPAN::Testers::Schema::Result::TestReport - Raw reports as JSON documents
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
